# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

from ...._types import FileTypes

__all__ = ["AndroidRestoreParams"]


class AndroidRestoreParams(TypedDict, total=False):
    backup: Required[FileTypes]
    """Backup file to restore (max file size: 100MB)"""
